 
 extern cherokee_plugin_info_t cherokee_error_redir_info; 
 extern cherokee_plugin_info_t cherokee_server_info_info; 
 extern cherokee_plugin_info_t cherokee_file_info; 
 extern cherokee_plugin_info_t cherokee_admin_info; 
 extern cherokee_plugin_info_t cherokee_dirlist_info; 
 extern cherokee_plugin_info_t cherokee_fcgi_info; 
 extern cherokee_plugin_info_t cherokee_fastcgi_info; 
 extern cherokee_plugin_info_t cherokee_scgi_info; 
 extern cherokee_plugin_info_t cherokee_redir_info; 
 extern cherokee_plugin_info_t cherokee_common_info; 
 extern cherokee_plugin_info_t cherokee_nn_info; 
 extern cherokee_plugin_info_t cherokee_cgi_info; 
 extern cherokee_plugin_info_t cherokee_phpcgi_info; 
 extern cherokee_plugin_info_t cherokee_mirror_info; 
 extern cherokee_plugin_info_t cherokee_gzip_info; 
 extern cherokee_plugin_info_t cherokee_ncsa_info; 
 extern cherokee_plugin_info_t cherokee_combined_info; 
 extern cherokee_plugin_info_t cherokee_w3c_info; 
 extern cherokee_plugin_info_t cherokee_ldap_info; 
 extern cherokee_plugin_info_t cherokee_htpasswd_info; 
 extern cherokee_plugin_info_t cherokee_plain_info; 
 extern cherokee_plugin_info_t cherokee_htdigest_info; 
 extern cherokee_plugin_info_t cherokee_round_robin_info; 
 extern cherokee_plugin_info_t cherokee_directory_info; 
 extern cherokee_plugin_info_t cherokee_extensions_info; 
 extern cherokee_plugin_info_t cherokee_request_info; 
 extern cherokee_plugin_info_t cherokee_header_info; 
 extern cherokee_plugin_info_t cherokee_not_info; 
 extern cherokee_plugin_info_t cherokee_and_info; 
 extern cherokee_plugin_info_t cherokee_or_info;
